#!/usr/bin/python
# -*- coding: utf-8 -*-

from Screens.Screen import Screen
from Components.Label import Label
from Components.Sources.StaticText import StaticText
from Components.ActionMap import ActionMap
from enigma import getDesktop, eFileWatch, eFileEvent
from datetime import datetime as DateTime

sz_w = getDesktop(0).size().width()

class TestPluginScreenFileWatch(Screen):

	if sz_w == 1920:	#1920 x 1080 FHD
		skin = """
		<screen name="TestPluginScreenFileWatch" position="center,150" size="1220,680">
			<ePixmap pixmap="skin_default/buttons/red.png" position="0,0" size="300,70" scale="stretch" alphatest="on" />
			<ePixmap pixmap="skin_default/buttons/green.png" position="300,0" size="300,70" scale="stretch" alphatest="on" />
			<ePixmap pixmap="skin_default/buttons/yellow.png" position="600,0" size="300,70" scale="stretch" alphatest="on" />
			<ePixmap pixmap="skin_default/buttons/blue.png" position="900,0" size="300,70" scale="stretch" alphatest="on" />
			<widget source="key_red" render="Label" position="0,0" zPosition="1" size="300,70" font="Regular;32" halign="center" valign="center" backgroundColor="#9f1313" transparent="1" />
			<widget source="key_green" render="Label" position="300,0" zPosition="1" size="300,70" font="Regular;32" halign="center" valign="center" backgroundColor="#1f771f" transparent="1" />
			<widget source="key_yellow" render="Label" position="600,0" zPosition="1" size="300,70" font="Regular;32" halign="center" valign="center" backgroundColor="#a08500" transparent="1" />
			<widget source="key_blue" render="Label" position="900,0" zPosition="1" size="300,70" font="Regular;32" halign="center" valign="center" backgroundColor="#18188b" transparent="1" />
			<widget name="status1" position="50,150" zPosition="1" size="600,100" font="Regular;32" halign="left" valign="center" backgroundColor="background" transparent="1" />
			<widget name="status2" position="50,300" zPosition="1" size="600,100" font="Regular;32" halign="left" valign="center" backgroundColor="background" transparent="1" />
		</screen>"""
	else:
		# HD 1280×720
		skin = """
		<screen name="TestPluginScreenFileWatch" position="center,100" size="800,500">
			<ePixmap pixmap="skin_default/buttons/red.png" position="0,0" size="200,40" scale="stretch" alphatest="on" />
			<ePixmap pixmap="skin_default/buttons/green.png" position="200,0" size="200,40" scale="stretch" alphatest="on" />
			<ePixmap pixmap="skin_default/buttons/yellow.png" position="400,0" size="200,40" scale="stretch" alphatest="on" />
			<ePixmap pixmap="skin_default/buttons/blue.png" position="600,0" size="200,40" scale="stretch" alphatest="on" />
			<widget source="key_red" render="Label" position="0,0" zPosition="1" size="200,40" font="Regular;22" halign="center" valign="center" backgroundColor="#9f1313" transparent="1" />
			<widget source="key_green" render="Label" position="200,0" zPosition="1" size="200,40" font="Regular;22" halign="center" valign="center" backgroundColor="#1f771f" transparent="1" />
			<widget source="key_yellow" render="Label" position="400,0" zPosition="1" size="200,40" font="Regular;22" halign="center" valign="center" backgroundColor="#a08500" transparent="1" />
			<widget source="key_blue" render="Label" position="600,0" zPosition="1" size="200,40" font="Regular;22" halign="center" valign="center" backgroundColor="#18188b" transparent="1" />
			<widget name="status1" position="20,100" zPosition="1" size="400,80" font="Regular;22" halign="left" valign="center" backgroundColor="background" transparent="1" />
			<widget name="status2" position="20,200" zPosition="1" size="400,80" font="Regular;22" halign="left" valign="center" backgroundColor="background" transparent="1" />
		</screen>"""	
		
	def __init__(self, session):
		Screen.__init__(self, session)
		
		self.setTitle("TEST - FileWatch")
		
		# Initialize widgets
		self["key_red"] = StaticText(_("Cancel"))
		self["key_green"] = StaticText(_("change File"))
		self["key_yellow"] = StaticText("start watch1")
		self["key_blue"] = StaticText("start watch2")
		self["status1"] = Label("status 1...")
		self["status2"] = Label("status 2...")
		
		# Define Actions
		self["actions"] = ActionMap(["SetupActions", "ColorActions"],
			{
				"cancel": 	self.close,
				"green": 	self.pos1,
				"yellow": 	self.pos2,
				"blue":		self.pos3,
			},-2)
		
		self.onLayoutFinish.append(self.layoutFinished)
	
	
	def layoutFinished(self):
		try:
			pass
			
		except:
			import traceback, sys
			traceback.print_exc()
	
	def pos1(self):
		
		try:
			testfile = open("/usr/lib/enigma2/python/Plugins/Extensions/TestPluginFileWatch/test.txt","w")
			testfile.write("test")
			testfile.close()
			
		except:
			import traceback, sys
			traceback.print_exc()
			
	
	
	def pos2(self):
		try:
			self.filewatch1 = eFileWatch("/usr/lib/enigma2/python/Plugins/Extensions/TestPluginFileWatch/test.txt", False, eFileEvent.CLOSE_WRITE)
			self.filewatch1_conn = self.filewatch1.fileChanged.connect(self.fileEvent1)
			self.filewatch1.startWatching()
			self["status1"].setText("status 1...\nstart watching test.txt in pluginfolder")
			
		except:
			import traceback
			traceback.print_exc()
	
	def fileEvent1(self, watch, event):
		timestr = format(DateTime.now(), '%H:%M:%S')
		self["status1"].setText("watch1 file changed - %s" % timestr)
		
	
	
	def pos3(self):
		try:
			file = "/usr/lib/enigma2/python/Plugins/Extensions/TestPluginFileWatch/test.txt"
			self.filewatch2 = eFileWatch(file, False, eFileEvent.CLOSE_WRITE)
			self.filewatch2_conn = self.filewatch2.fileChanged.connect(self.fileEvent2)
			self.filewatch2.startWatching()
			self["status2"].setText("status 2...\nstart watching test.txt in pluginfolder")
			
		except:
			import traceback
			traceback.print_exc()
			
	def fileEvent2(self, watch, event):
		timestr = format(DateTime.now(), '%H:%M:%S')
		self["status2"].setText("watch2 file changed - %s" % timestr)
		

